@@ -48,6 +48,10 @@ snowSuperLearner <- function(cluster, Y, X, newX = NULL, family = gaussian(), SL
 	Z <- matrix(NA, N, k)
 	libraryNames <- paste(library$library$predAlgorithm, library$screenAlgorithm[library$library$rowScreen], sep="_")
 
+  if(p < 2 & !identical(library$screenAlgorithm, "All")) {
+    warning('Screening algorithms specified in combination with single-column X.')
+  }
+
 	# put fitLibrary in it's own environment to locate later
 	fitLibEnv <- new.env()
 	assign('fitLibrary', vector('list', length = k), envir = fitLibEnv)
@@ -196,11 +200,12 @@ snowSuperLearner <- function(cluster, Y, X, newX = NULL, family = gaussian(), SL
 
   time_predict = system.time({
 
-    if (length(library$screenAlgorithm) < 2) {
-      whichScreen <- t(sapply(library$screenAlgorithm, FUN = .screenFun, list = list(Y = Y, X = X, family = family, id = id, obsWeights = obsWeights)))
+    whichScreen <- if (length(library$screenAlgorithm) < 2) {
+      sapply(library$screenAlgorithm, FUN = .screenFun, list = list(Y = Y, X = X, family = family, id = id, obsWeights = obsWeights), simplify = FALSE)
     } else {
-      whichScreen <- t(parallel::parSapply(cl = cluster, X = library$screenAlgorithm, FUN = .screenFun, list = list(Y = Y, X = X, family = family, id = id, obsWeights = obsWeights)))
+      parallel::parSapply(cl = cluster, X = library$screenAlgorithm, FUN = .screenFun, list = list(Y = Y, X = X, family = family, id = id, obsWeights = obsWeights), simplify = FALSE)
     }
+    whichScreen <- do.call(rbind, whichScreen)
     # change to sapply?
     # for(s in 1:k) {
     #   testAlg <- try(do.call(library$library$predAlgorithm[s], list(Y = Y, X = subset(X, select = whichScreen[library$library$rowScreen[s], ], drop=FALSE), newX = subset(newX, select = whichScreen[library$library$rowScreen[s], ], drop=FALSE), family = family, id = id, obsWeights = obsWeights)))
