@@ -1,3 +1,6 @@
+library(SuperLearner)
+if(all(sapply(c("testthat", "randomForest", "glmnet"), requireNamespace))) {
+
 ########################
 # Simulate data
 set.seed(23432)
@@ -16,22 +19,24 @@ SL.library = c("SL.randomForest", "SL.glmnet", "SL.glm", "SL.mean")
 # default split: 80% in training, 20% in validation
 defaultSplit = formals(SampleSplitSuperLearner)$split
 sssl1 = SampleSplitSuperLearner(Y = Y, X = X, SL.library = SL.library)
-expect_equal(length(sssl1$validRows), (1 - defaultSplit) * n)
-expect_false(any(sssl1$errorsInLibrary))
-expect_false(any(sssl1$errorsInCVLibrary))
+testthat::expect_equal(length(sssl1$validRows), (1 - defaultSplit) * n)
+testthat::expect_false(any(sssl1$errorsInLibrary))
+testthat::expect_false(any(sssl1$errorsInCVLibrary))
 
 # split by specifying row numbers in validation set
 validRows = seq(from = round(n/5), to = n, by = round(n/10))
 sssl2 = SampleSplitSuperLearner(Y = Y, X = X, SL.library = SL.library,
 								split = validRows)
-expect_equal(sssl2$validRows, validRows)
-expect_false(any(sssl2$errorsInLibrary))
-expect_false(any(sssl2$errorsInCVLibrary))
+testthat::expect_equal(sssl2$validRows, validRows)
+testthat::expect_false(any(sssl2$errorsInLibrary))
+testthat::expect_false(any(sssl2$errorsInCVLibrary))
 
 # split with only one observation in validation set
 validRows = 1
 sssl3 = SampleSplitSuperLearner(Y = Y, X = X, SL.library = SL.library,
 								split = validRows)
-expect_equal(sssl3$validRows, validRows)
-expect_false(any(sssl3$errorsInLibrary))
-expect_false(any(sssl3$errorsInCVLibrary))
\ No newline at end of file
+testthat::expect_equal(sssl3$validRows, validRows)
+testthat::expect_false(any(sssl3$errorsInLibrary))
+testthat::expect_false(any(sssl3$errorsInCVLibrary))
+	
+}
