@@ -43,11 +43,11 @@ summary(pred$pred)
 testthat::test_that("Test create.SL.xgboost", {
   # Create a new environment to hold the functions.
   sl_env = new.env()
-  xgb_grid = create.SL.xgboost(tune = list(ntrees = c(5), max_depth = c(1),
-                      minobspernode = 10, shrinkage = c(0.01, 0.001)), env = sl_env)
+  xgb_grid = create.SL.xgboost(tune = list(ntrees = c(5, 10), max_depth = c(1, 2),
+                      minobspernode = 10, shrinkage = c(0.1, 0.01, 0.001)), env = sl_env)
   xgb_grid
   xgb_functions = ls(sl_env)
-  testthat::expect_equal(length(xgb_functions), 2)
+  testthat::expect_equal(length(xgb_functions), 12)
   # Load the functions for use in the SuperLearner call.
   attach(sl_env)
   sl <- SuperLearner(Y = Y_reg, X = X, SL.library = c(SL.library, xgb_grid$names),
